<?php

namespace MuseumWP\Classes;

use MuseumWP\DataStores\ArchiveStore;
use MuseumWP\DataStores\AuthorStore;
use MuseumWP\DataStores\CategoryStore;
use MuseumWP\DataStores\IndexStore;
use MuseumWP\DataStores\MainStore;
use MuseumWP\DataStores\NotFoundStore;
use MuseumWP\DataStores\PageStore;
use MuseumWP\DataStores\PostStore;
use MuseumWP\DataStores\SearchStore;
use MuseumWP\DataStores\ShopStore;
use MuseumWP\DataStores\TagStore;
use MuseumWP\Util\Arr;

/**
 * The data store class.
 */
class DataStore
{
	/**
	 * Data Stores.
	 * 
	 * @var array
	 */
	private static $stores = [
		'404'		=> NotFoundStore::class,
		'archive'	=> ArchiveStore::class,
		'author'	=> AuthorStore::class,
		'category'	=> CategoryStore::class,
		'index'		=> IndexStore::class,
		'page'		=> PageStore::class,
		'post'		=> PostStore::class,
		'search'	=> SearchStore::class,
		'tag'		=> TagStore::class,
		'shop'		=> ShopStore::class,
	];

	/**
	 * Default data store.
	 */
	const DEFAULT = MainStore::class;

	/**
	 * Current data store.
	 * 
	 * @var string
	 */
	public static $store = '';

	/**
	 * Init
	 * 
	 * @param  string $store key to get the store.
	 * @return void
	 */
	public static function init($store) {
		self::initStore($store);
	}

	/**
	 * Init Store.
	 *
	 * @param  [type] $store [description]
	 * @return [type]        [description]
	 */
	private static function initStore($store) {
		$store = Arr::get(self::$stores, $store, self::DEFAULT);

		if (class_exists($store)) {
			self::$store = new $store;

			self::$store->setData();
		}

	}

	/**
	 * Get store;
	 * @param  [type] $store [description]
	 * @return [type]        [description]
	 */
	public static function getStore($store = '') {

		return Arr::get(self::$stores, $store, self::DEFAULT);
	}
}