<?php

namespace MuseumWP\Classes;


class Enqueue
{

	public static function init() {

		$map_api = museumwp_options("map_api");

		// Load the html5 shiv.
		wp_enqueue_script( 'respond.min', get_template_directory_uri() . '/js/html5/respond.min.js' );
		wp_script_add_data( 'respond.min', 'conditional', 'lt IE 9' );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		if( $map_api != "" ) {
			wp_register_script( 'google-map', 'https://maps.googleapis.com/maps/api/js?key='.$map_api );
		}
		else {
			wp_register_script( 'google-map', 'https://maps.googleapis.com/maps/api/js?v=3.exp' );
		}
		/* Lib */
		wp_register_script( 'gmap-lib', get_template_directory_uri() . '/assets/js/gmap.js', array( 'google-map' ), '1.0', true );
		wp_enqueue_style( 'museumwp-lib', get_template_directory_uri() . '/assets/css/lib.css');
		wp_enqueue_script( 'museumwp-lib', get_template_directory_uri() . '/assets/js/lib.js', array( 'jquery' ) );

		wp_add_inline_script( 'museumwp-lib', '
			var templateUrl = "'.esc_url( get_template_directory_uri() ).'";
			var WPAjaxUrl = "'.esc_url( admin_url( 'admin-ajax.php' ) ).'";
		');
		
		/* Google Font */
		wp_enqueue_style( 'museumwp-fonts', self::fonts_url() );
		
		wp_enqueue_style( 'dashicons' );

		/* Main Stylesheet */
		wp_enqueue_style( 'museumwp-stylesheet', get_template_directory_uri() . '/assets/css/style.css' );
		wp_enqueue_style( 'museumwp-custom-stylesheet', get_template_directory_uri() . '/assets/css/custom.css' );

		/* Custom Functions JS */
		wp_enqueue_script( 'museumwp-functions', get_template_directory_uri() . '/assets/js/functions.js' );
	}


	private static function fonts_url() {

		$fonts_url = '';
		
		$montserrat = _x( 'on', 'Montserrat font: on or off', "museumwp" );
		$raleway = _x( 'on', 'Raleway font: on or off', "museumwp" );
		$open_sans = _x( 'on', 'Open Sans font: on or off', "museumwp" );

		if ( 'off' !== $raleway || 'off' !== $montserrat || 'off' !== $open_sans ) {

			$font_families = array(); 
			if ( 'off' !== $raleway ) {
				$font_families[] = 'Raleway:500,600,700,100,800,900,400,200,300';
			}
			
			if ( 'off' !== $montserrat ) {
				$font_families[] = 'Montserrat:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
			}
			
			if ( 'off' !== $open_sans ) {
				$font_families[] = 'Open Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
			}

			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);

			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		}

		return esc_url_raw( $fonts_url );
	}
}