<?php

namespace MuseumWP\Classes;


class Setup
{
	public static function init() {
		/* load theme languages */
		load_theme_textdomain( 'museumwp', get_template_directory() . '/languages' );

		/* Muse Image Sizes */
		add_image_size( 'museumwp-360-278', 360, 278, true );
		add_image_size( 'museumwp-311-667', 311, 667, true );

		set_post_thumbnail_size( 823, 365, true ); /* Default Featured Image */

		// This theme uses wp_nav_menu() in two locations.
		register_nav_menus( array(
			'primary'   => __( 'Primary menu', "museumwp" ),
			'footer'   => __( 'Footer menu', "museumwp" ),
		) );

		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );

		/* WooCommerce Theme Support */
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );

		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );

		/*
		 * Enable support for Post Formats.
		 *
		 * See: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array( 'gallery' ) );

		add_action('widgets_init', [__CLASS__, 'widgets']);

		(new Hooks)->boot();
	}

	public static function tgmpa() {
		/*
		 * Array of plugin arrays. Required keys are name and slug.
		 * If the source is NOT from the .org repo, then source is also required.
		 */
		$plugins = array(

			array(
				'name' => esc_html__('Museumwp Core', 'museumwp'), // The plugin name.
				'slug' => 'museum-core', // The plugin slug (typically the folder name).
				'source' => 'https://premiumlayers.com/plugins/museum-core.zip', // The plugin source.
				'required' => true, // If false, the plugin is only 'recommended' instead of required.
				'version' => '1.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
				'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
				'external_url' => '', // If set, overrides default API URL and points to an external URL.
			),
			
			array(
				'name' => esc_html__('Revolution Slider', 'museumwp'), // The plugin name.
				'slug' => 'revslider', // The plugin slug (typically the folder name).
				'source' => 'https://premiumlayers.com/plugins/revslider.zip', // The plugin source.
				'required' => true, // If false, the plugin is only 'recommended' instead of required.
				'version' => '5.4.8', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
				'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
				'external_url' => '', // If set, overrides default API URL and points to an external URL.
			),
			array(
				'name'               => esc_html__('The Events Calendar', 'museumwp'), // The plugin name.
				'slug'               => 'the-events-calendar', // The plugin slug (typically the folder name).
				'required'           => true,
			),
			array(
				'name'               => esc_html__('Custom Sidebars', 'museumwp'), // The plugin name.
				'slug'               => 'custom-sidebars', // The plugin slug (typically the folder name).
				'required'           => true,
			),
			array(
	            'name'               => esc_html__('Custom Fields', 'museumwp'), // The plugin name.
	            'slug'               => 'advanced-custom-fields', // The plugin slug (typically the folder name).
				'required'           => true,
	        ),
	        array(
	            'name'               => esc_html__('WP Forms', 'museumwp'), // The plugin name.
	            'slug'               => 'wpforms-lite', // The plugin slug (typically the folder name).
				'required'           => true,
	        ),
	        array(
				'name'               => esc_html__('WooCommerce', 'museumwp'), // The plugin name.
				'slug'               => 'woocommerce', // The plugin slug (typically the folder name).
				'required'           => true,
			),
			array(
				'name'               => esc_html__('YITH WooCommerce Wishlist', 'museumwp'), // The plugin name.
				'slug'               => 'yith-woocommerce-wishlist', // The plugin slug (typically the folder name).
				'required'           => true,
			),
			
		);

		if(! function_exists('vc_map')) {

			$plugins[] = array(
	            'name'               => esc_html__('Elementor', 'museumwp'), // The plugin name.
	            'slug'               => 'elementor', // The plugin slug (typically the folder name).
				'required'           => true,
	        );
		}

		if(! class_exists('Elementor\\Plugin')) {

			$plugins[] = array(
				'name' => esc_html__('Visual Composer', 'museumwp'), // The plugin name.
				'slug' => 'js_composer', // The plugin slug (typically the folder name).
				'source' => 'https://premiumlayers.com/plugins/js_composer.zip', // The plugin source.
				'required' => true, // If false, the plugin is only 'recommended' instead of required.
				'version' => '5.5.2', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
				'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
				'external_url' => '', // If set, overrides default API URL and points to an external URL.
			);
		}
		

		/*
		 * Array of configuration settings. Amend each line as needed.
		 *
		 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
		 * strings available, please help us make TGMPA even better by giving us access to these translations or by
		 * sending in a pull-request with .po file(s) with the translations.
		 *
		 * Only uncomment the strings in the config array if you want to customize the strings.
		 */
		$config = array(
			'id'           => 'museumwp',                 // Unique ID for hashing notices for multiple instances of TGMPA.
			'default_path' => '',                      // Default absolute path to bundled plugins.
			'menu'         => 'tgmpa-install-plugins', // Menu slug.
			'has_notices'  => true,                    // Show admin notices or not.
			'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
			'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
			'is_automatic' => false,                   // Automatically activate plugins after installation or not.
			'message'      => '',                      // Message to output right before the plugins table.
		);

		tgmpa( $plugins, $config );
	}

	public static function widgets() {

		/**
		 * Creates a sidebar
		 * @param string|array  Builds Sidebar based off of 'name' and 'id' values.
		 */
		register_sidebar(
			array(
				'name'          => esc_html__( 'Default Sidebar', 'museumwp' ),
				'id'            => 'default-sidebar',
				'description'   => '',
				'class'         => '',
				'before_widget' => '<div id="%1$s" class="widget sidebar-widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5 class="widget-title">',
				'after_title'   => '</h5>',
			)
		);

		add_filter('excerpt_length', function($len) {
			return 100;
		});
		
	}
}