<?php

namespace MuseumWP\DataStores;

use MuseumWP\Util\Arr;

class PostStore extends Store
{
	public static $layout = 'right';
	public static $sidebar = 'default-sidebar';
	public static $meta = true;
	public static $banner = true;
	public static $banner_bg = '';
	public static $banner_src = 'd';
	public static $banner_elementor = '';
	public static $banner_title = '';
	public static $banner_subtitle = '';
	public static $breads = true;
	public static $date = true;
	public static $author = true;
	public static $comments = true;
	public static $tags = true;
	public static $cats = false;
	public static $shares = true;
	public static $facebook = true;
	public static $twitter = true;
	public static $pinterest = true;
	public static $linkedin = true;
	public static $tumblr = true;
	public static $reddit = true;
	public static $digg = true;

	public function setData() {


		$meta = $this->getMeta();
		$defaults = $this->defaults();
		$value = [];
		if(Arr::get($meta, 'sidebar_source') == 'd') {
			$value = [
				'layout'	=> Arr::get($meta, 'sidebar_layout'),
				'sidebar'	=> Arr::get($meta, 'sidebar_page_sidebar'),
			];
		}

		$value = wp_parse_args( $value, $defaults );
		foreach($value as $key => $val) {
			if(isset(self::${$key}) ) {
				self::${$key} = $val;
			}
		}

		self::setBanner($meta);
	}

	/**
	 * Get associative array of post meta.
	 *
	 * @return array
	 */
	private function getMeta() {
		$meta = get_post_meta(get_the_id());

		$return = [];

		foreach($meta as $key => $mt) {
			$return[ $key ] = maybe_unserialize( $mt[0] );
		}

		return $return;
	}

	private function setBanner($meta) {
		self::$banner = Arr::get($meta, 'show_banner', self::$banner);
		self::$banner_bg = wp_get_attachment_url( Arr::get($meta, 'banner_bg', self::$banner_bg) );
		self::$banner_title = Arr::get($meta, 'banner_title', get_the_title());
		self::$banner_src = Arr::get($meta, 'banner_source_type');
		self::$banner_elementor = Arr::get($meta, 'banner_elementor_template');
	}

	/**
	 * Default values.
	 * @return [type] [description]
	 */
	private function defaults() {
		$options = museumwp_options();

		return [
			'layout'	=> Arr::get($options, 'post_sidebar_layout', 'full'),
			'sidebar'	=> Arr::get($options, 'single_post_sidebar', 'default-sidebar'),
			'banner'	=> Arr::get($options, 'single_post_show_banner', false),
			'banner_bg'	=> Arr::get($options, 'single_post_banner_bg_image.url'),
			'breads'	=> Arr::get($options, 'single_post_show_breads', false),
			'meta'		=> Arr::get($options, 'single_post_show_meta', false),
			'date'		=> Arr::get($options, 'single_post_date', false),
			'author'	=> Arr::get($options, 'single_post_author', false),
			'comments'	=> Arr::get($options, 'single_post_comments', false),
			'tags'		=> Arr::get($options, 'single_post_tags', false),
			'cats'		=> Arr::get($options, 'single_post_cats', false),
			'shares'	=> Arr::get($options, 'post_socials_sharing', false),
			'facebook'	=> Arr::get($options, 'post_facebook_sharing', false),
			'twitter'	=> Arr::get($options, 'post_twitter_sharing', false),
			'linkedin'	=> Arr::get($options, 'post_linkedin_sharing', false),
			'pinterest'	=> Arr::get($options, 'post_pinterest_sharing', false),
			'reddit'	=> Arr::get($options, 'post_reddit_sharing', false),
			'digg'		=> Arr::get($options, 'post_digg_sharing', false),
			'tumblr'	=> Arr::get($options, 'post_tumblr_sharing', false),
		];
	}

	/**
	 * Get properties.
	 *
	 * @param  [type] $prop [description]
	 * @return [type]       [description]
	 */
	public static function getProp($prop) {
		if(property_exists(__CLASS__, $prop)) {
			return self::${$prop};
		}
		return '';
	}
}