<?php

namespace MuseumWP\DataStores;

use MuseumWP\Util\Arr;

class ShopStore extends Store
{
	public static $layout = 'right';
	public static $sidebar = 'default-sidebar';
	public static $meta = false;
	public static $banner = true;
	public static $banner_bg = '';
	public static $banner_src = 'd';
	public static $banner_elementor = '';
	public static $banner_title = '';
	public static $banner_subtitle = '';
	public static $breads = true;
	public static $date = false;
	public static $author = false;
	public static $comments = false;
	public static $shares = false;
	public static $facebook = false;
	public static $twitter = false;
	public static $pinterest = false;
	public static $linkedin = false;
	public static $tumblr = false;
	public static $reddit = false;
	public static $digg = false;

	public function setData() {


		$meta = $this->getMeta();
		$defaults = $this->defaults();
		$value = [];
		if(Arr::get($meta, 'sidebar_source') == 'd') {
			$value = [
				'layout'	=> Arr::get($meta, 'sidebar_layout', 'right'),
				'sidebar'	=> Arr::get($meta, 'sidebar_page_sidebar', 'sidebar-1'),
			];
		}

		$value = wp_parse_args( $value, $defaults );
		foreach($value as $key => $val) {
			if(isset(self::${$key}) ) {
				self::${$key} = $val;
			}
		}

		self::setBanner($meta);
	}

	/**
	 * Get associative array of post meta.
	 *
	 * @return array
	 */
	private function getMeta() {
		// echo wc_get_page_id('shop');exit;
		$id = is_singular( 'product' ) ? get_the_id() : wc_get_page_id('shop');
		$meta = get_post_meta( $id );
		if(is_tax()) {
			$meta = get_term_meta(get_queried_object_id());
		}
		$return = [];

		foreach($meta as $key => $mt) {
			$return[ $key ] = maybe_unserialize( $mt[0] );
		}

		return $return;
	}

	private function setBanner($meta) {
		$title = (is_tax()) ? single_term_title( '', false ) : get_the_title();
		self::$banner = (bool)Arr::get($meta, 'show_banner', true);

		self::$banner_bg = wp_get_attachment_url( Arr::get($meta, 'banner_bg', self::$banner_bg) );
		self::$banner_title = Arr::get($meta, 'banner_title', $title);
		self::$banner_subtitle = Arr::get($meta, 'banner_subtitle');
		self::$banner_src = Arr::get($meta, 'banner_source_type', 'd');
		self::$banner_elementor = Arr::get($meta, 'banner_elementor_template');
	}

	/**
	 * Default values.
	 * @return [type] [description]
	 */
	private function defaults() {
		$options = museumwp_options();

		return [
			'layout'	=> Arr::get($options, 'page_sidebar_layout', 'riht'),
			'sidebar'	=> Arr::get($options, 'shop_page_sidebar', 'sidebar-1'),
			'banner'	=> Arr::get($options, 'shop_page_show_banner', true),
			'banner_bg'	=> Arr::get($options, 'shop_page_banner_bg_image.url'),
			'breads'	=> true,
			'meta'		=> Arr::get($options, 'shop_page_show_meta', false),
			'date'		=> Arr::get($options, 'shop_page_date', false),
			'author'	=> Arr::get($options, 'shop_page_author', false),
			'comments'	=> Arr::get($options, 'shop_page_comments', false),
			'shares'	=> Arr::get($options, 'shop_socials_sharing', false),
			'facebook'	=> Arr::get($options, 'shop_facebook_sharing', false),
			'twitter'	=> Arr::get($options, 'shop_twitter_sharing', false),
			'linkedin'	=> Arr::get($options, 'shop_linkedin_sharing', false),
			'pinterest'	=> Arr::get($options, 'shop_pinterest_sharing', false),
			'reddit'	=> Arr::get($options, 'shop_reddit_sharing', false),
			'digg'		=> Arr::get($options, 'shop_digg_sharing', false),
			'tumblr'	=> Arr::get($options, 'shop_tumblr_sharing', false),
		];
	}

	/**
	 * Get properties.
	 *
	 * @param  [type] $prop [description]
	 * @return [type]       [description]
	 */
	public static function getProp($prop) {
		if(property_exists(__CLASS__, $prop)) {
			return self::${$prop};
		}
		return '';
	}
}