<?php

use MuseumWP\Util\Arr;

if( ! function_exists('museumwp_options') ) {
	/**
	 * Theme options.
	 * 
	 * @return [type] [description]
	 */
	function museumwp_options($key = '', $def = '') {
		global $museum_options;

		if( $key ) {
			if(class_exists('MuseumCore\Util\Arr')) {
				return MuseumCore\Util\Arr::get($museum_options, $key, $def);
			}
			return museum_get( $museum_options, $key );
		}
		return $museum_options;
	}
}

if( ! function_exists( 'museum_get' ) ) {
	function museum_get($var, $key, $def = '') {
		if(is_array($var)) {
			if(class_exists('MuseumCore\Util\Arr')) {
				return MuseumCore\Util\Arr::get($var, $key, $def);
			}
			return isset( $var[ $key ] ) ? $var[ $key ] : $def;
		} elseif( is_object( $var ) ) {
			return isset( $var->{$key} ) ? $var->{$key} : $def;
		}

		return $def;
	}
}


/**
 * [studentwp_the_breadcrumb description]
 *
 * @return [type] [description]
 */
function museumwp_the_breadcrumb() {

	global $wp_query;
	$queried_object = get_queried_object();

	$breadcrumb = '';
	$delimiter = ' ';
	$before = '<span property="itemListElement" typeof="ListItem">';
	$after = '</span>';

	$taxonomies = array( 'product_cat', 'category', 'course_cat', 'gallery_tag', 'tribe_events_cat' );

	if (!is_home()) {
		$breadcrumb .= $before . '<a href="' . esc_url( home_url('/') ) . '" title="' . esc_attr( get_bloginfo( 'name' ) ) . '">' . esc_html__('Home', 'museumwp') . '</a>' . $after;

		/** If category or single post */
		if (is_category()) {
			$cat_obj = $wp_query->get_queried_object();
			$this_category = get_category($cat_obj->term_id);

			if ($this_category->parent != 0) {
				$parent_category = get_category($this_category->parent);
				$breadcrumb .= get_category_parents($parent_category, TRUE, $delimiter);
			}

			$breadcrumb .= $delimiter . $before . '<a href="' . get_category_link(get_query_var('cat')) . '">' . single_cat_title('', FALSE) . '</a>' . $after;
		} elseif (is_tax()) {
			$breadcrumb .= $delimiter . $before . '<a href="' . get_term_link($queried_object) . '">' . $queried_object->name . '</a>' . $after;
		} elseif (is_page()) /** If WP pages */ {
			global $post;
			if ($post->post_parent) {
				$anc = get_post_ancestors($post->ID);
				foreach ($anc as $ancestor) {
					$breadcrumb .= $delimiter . $before . '<a href="' . get_permalink($ancestor) . '">' . get_the_title($ancestor) . '</a>' . $after;
				}
				$breadcrumb .= $delimiter . $before . get_the_title($post->ID) . $after;
			} else
			$breadcrumb .= $delimiter . $before . '' . get_the_title() . '' . $after;
		}
		elseif (is_singular()) {
			if ($category = wp_get_object_terms(get_the_ID(), $taxonomies, array( 'order' => 'DESC' ) ) ) {
				if (!is_wp_error($category)) {
					$breadcrumb .= $delimiter . $before . '<a href="' . get_term_link(Arr::get($category, '0')) . '">' . Arr::get(Arr::get($category, '0'), 'name') . '</a>' . $after;
					$breadcrumb .= $delimiter . $before . '' . get_the_title() . '' . $after;
				} else
				$breadcrumb .= $delimiter . $before . '' . get_the_title() . '' . $after;
			}else {
				$breadcrumb .= $delimiter . $before . '' . get_the_title() . '' . $after;
			}
		} elseif (is_tag())
		$breadcrumb .= $delimiter . $before . '<a href="' . get_term_link($queried_object) . '">' . single_tag_title('', FALSE) . '</a>' . $after; /*             * If tag template */
		elseif (is_day())
			$breadcrumb .= $delimiter . $before . '<a href="">' . esc_html__('Archive for ', 'museumwp') . get_the_time('F jS, Y') . '</a>' . $after;/** If daily Archives */
		elseif (is_month())
			$breadcrumb .= $delimiter . $before . '<a href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '">' . esc_html__('Archive for ', 'museumwp') . get_the_time('F, Y') . '</a>' . $after;/** If montly Archives */
		elseif (is_year())
			$breadcrumb .= $delimiter . $before . '<a href="' . get_year_link(get_the_time('Y')) . '">' . esc_html__('Archive for ', 'museumwp') . get_the_time('Y') . '</a>' . $after;/** If year Archives */
		elseif (is_author())
			$breadcrumb .= $delimiter . $before . '<a href="' . esc_url(get_author_posts_url(get_the_author_meta("ID"))) . '">' . esc_html__('Archive for ', 'museumwp') . get_the_author() . '</a>' . $after;/** If author Archives */
		elseif (is_search())
			$breadcrumb .= $delimiter . $before . '' . esc_html__('Search Results for ', 'museumwp') . get_search_query() . '' . $after;/** if search template */
		elseif (is_404())
			$breadcrumb .= $delimiter . $before . '' . esc_html__('404 - Not Found', 'museumwp') . '' . $after;/** if search template */
		elseif (is_post_type_archive('product')) {

			$shop_page_id = wc_get_page_id('shop');
			if (get_option('page_on_front') !== $shop_page_id) {
				$shop_page = get_post($shop_page_id);

				$_name = wc_get_page_id('shop') ? get_the_title(wc_get_page_id('shop')) : '';

				if (!$_name) {
					$product_post_type = get_post_type_object('product');
					$_name = $product_post_type->labels->singular_name;
				}

				if (is_search()) {

					$breadcrumb .= $before . '<a href="' . get_post_type_archive_link('product') . '">' . $_name . '</a>' . $delimiter . esc_html__('Search results for &ldquo;', 'museumwp') . get_search_query() . '&rdquo;' . $after;
				} elseif (is_paged()) {

					$breadcrumb .= $before . '<a href="' . get_post_type_archive_link('product') . '">' . $_name . '</a>' . $after;
				} else {

					$breadcrumb .= $before . $_name . $after;
				}
			}
		} else
		$breadcrumb .= $delimiter . $before . '<a href="' . get_permalink() . '">' . get_the_title() . '</a>' . $after;/** Default value */
	}

	return $breadcrumb;
}